/*For detail informations look at the Stepper Motor Header file.
 *@author Yuri Gbur 
 *updated: 01/03/14
 */

#include "StepperMotor.h"
#include "Arduino.h"

StepperMotor::StepperMotor(){            // constructs an instance with default values, there shouldn't be negative pins, so no pins are selected. It doesn't create a global delay value.
  StepperMotor(-1,-1,0);

}
StepperMotor::StepperMotor(int stp, int dir){   // constructs an Instance with the given Pins selected. It doesn't create a global delay value.
  this->stp = stp;
  this->dir = dir;
  this->delayValue = 0;        //wieso? man kann einen konstruktor keinen anderen konstruktor aufrufen lassen
  direction = Undefined;                                    //the global direction is always undefined while constucting an instance of the Stepper Motor.
  pinMode(stp, OUTPUT);       //TODO: für negative werte testen!  ????
  pinMode(dir, OUTPUT);
}
StepperMotor::StepperMotor(int stp, int dir, int delayValue){ //constructs an Instance with the given pins and a given delay value.
  this->stp = stp;
  this->dir = dir;
  this->delayValue = delayValue;
  direction = Undefined;                                    //the global direction is always undefined while constucting an instance of the Stepper Motor.
  pinMode(stp, OUTPUT);       //TODO: für negative werte testen!
  pinMode(dir, OUTPUT);
}
void StepperMotor::setGlobalDelay(int delayValue){
  this->delayValue = delayValue;
}
void StepperMotor::setDir(Direction newdir){  
  direction = newdir;
}  
void StepperMotor::stepLeft(){
  digitalWrite(dir, HIGH);
  digitalWrite(stp, HIGH);
  delay(delayValue);
  digitalWrite(stp, LOW);
  delay(delayValue);
}  
void StepperMotor::stepRight(){
  digitalWrite(dir, LOW);
  digitalWrite(stp, HIGH);
  delay(delayValue);
  digitalWrite(stp, LOW);
  delay(delayValue);
}  
void StepperMotor::doStep(Direction newdir){        //compares the possibilities for the enum with the given direction. 
  switch(newdir){
  case RIGHT:
    digitalWrite(dir, HIGH);
    digitalWrite(stp, HIGH);
    delay(delayValue);
    digitalWrite(stp, LOW);
    delay(delayValue);
    break;  
  case LEFT:
    digitalWrite(dir, LOW);
    digitalWrite(stp, HIGH);
    delay(delayValue);
    digitalWrite(stp, LOW);
    delay(delayValue);
    break;
  case Undefined:
    break;
  }
}
void StepperMotor::stepsLeft(int steps){
  digitalWrite(dir, LOW);
  for(int i=0;i<steps;i++){
    digitalWrite(stp, HIGH);
    delay(delayValue);
    digitalWrite(stp, LOW);
    delay(delayValue);
  }
}
void StepperMotor::stepsRight(int steps){
  digitalWrite(dir, HIGH);
  for(int i=0;i<steps;i++){
    digitalWrite(stp, HIGH);
    delay(delayValue);
    digitalWrite(stp, LOW);
    delay(delayValue);
  }
}
void StepperMotor::stepLeft(int delayValue){
  digitalWrite(dir, LOW);
  digitalWrite(stp, HIGH);
  delay(delayValue);
  digitalWrite(stp, LOW);
  delay(delayValue);
}
void StepperMotor::stepRight(int delayValue){
  digitalWrite(dir, HIGH);
  digitalWrite(stp, HIGH);
  delay(delayValue);
  digitalWrite(stp, LOW);
  delay(delayValue);
}  
void StepperMotor::setStepPin(int stp){
  this->stp = stp;
}  
void StepperMotor::setDirPin(int dir){
  this->dir = dir;
}


